@@ -306,16 +306,16 @@ CHAIN_APIS = {
         "chain-registry": "https://raw.githubusercontent.com/cosmos/chain-registry/master/cronos/chain.json"
     },
     'evmos': {
-        "denom": "",
-        "name": "",
-        "coingecko_id": "",
+        "denom": "uevmos",
+        "name": "Evmos",
+        "coingecko_id": "evmos",
         "explorers": {
             "ping": "https://ping.pub/evmos",
             "mintscan": "https://www.mintscan.io/evmos",
-            "keplr": "https://wallet.keplr.app/chains/evmos/proposals"
+            "keplr": "https://wallet.keplr.app/chains/evmos"
         },
-        "rest_root": "https://lcd.evmos.ezstaking.io/",
-        "rpc_root": "",
+        "rest_root": "https://rest.cosmos.directory/evmos",
+        "rpc_root": "https://rpc.cosmos.directory/evmos",
         "twitter": "@EvmosOrg",
         "logo": "https://raw.githubusercontent.com/cosmos/chain-registry/master/evmos/images/evmos.png",
         "chain-registry": "https://raw.githubusercontent.com/cosmos/chain-registry/master/evmos/chain.json"
@@ -521,6 +521,19 @@ CHAIN_APIS = {
         "logo": "https://raw.githubusercontent.com/cosmos/chain-registry/master/terra2/images/luna.png",
         "chain-registry": "https://raw.githubusercontent.com/cosmos/chain-registry/master/terra2/chain.json"
     },
+    'passage': {
+        "denom": "upasg",
+        "name": "Passage",
+        "explorers": {
+            "ping": 'https://ping.pub/passage',
+            "mintscan": 'https://www.mintscan.io/passage',  
+        },
+        "rest_root": "https://rest.cosmos.directory/passage", # https://rest.cosmos.directory/juno
+        "rpc_root": "https://rpc.cosmos.directory/passage",
+        "twitter": "@Passage3D",
+        "logo": "https://github.com/cosmos/chain-registry/raw/master/passage/images/pasg.png",
+        "chain-registry": "https://raw.githubusercontent.com/cosmos/chain-registry/master/passage/chain.json",
+    },
     'umee': {
         "denom": "uumee",
         "name": "umee",
@@ -538,6 +551,10 @@ CHAIN_APIS = {
     },
 }
 
+# TODO: Wallet prefixes -> CHAIN_APIs here for py gov bot.
+WALLETS = {}
+
+# Normal names / aliases here
 aliases = {
     # alias: name in CHAIN_APIS
     "terra-classic": "terraC",
@@ -553,7 +570,8 @@ aliases = {
     "cosmos": "atom",
     "osmosis": "osmo",
     "chihuahua": "huahua",
-    "dig-chain": "dig"
+    "dig-chain": "dig",
+    "passage": "pasg",
 }
 
 def get_chain(name):
@@ -581,4 +599,4 @@ def get_endpoint(key) -> str:
     return REST_ENDPOINTS.get(key, "")
 
 if __name__ == "__main__":
-    print(get_chain('dig-chain'))
\ No newline at end of file
+    print(get_chain('dig-chain'))
